@@ -41,6 +41,16 @@ servers = {
     'darwin': {
         'endpoint': 'http://seeclickfix.com/aus_darwin/open311/'
     },
+    'dc': {
+        'endpoint': 'http://app.311.dc.gov/CWI/Open311/v2/',
+        'format': 'xml',
+        'jurisdiction': 'dc.gov'
+    },
+    'district of columbia': {
+        'endpoint': 'http://app.311.dc.gov/CWI/Open311/v2/',
+        'format': 'xml',
+        'jurisdiction': 'dc.gov'
+    },
     'deleon': {
         'endpoint': 'http://seeclickfix.com/de-leon/open311/'
     },
